@@ -1,4 +1,4 @@
 from __future__ import absolute_import, unicode_literals
 from .base import Option
 
-__all__ = ['Option']
+__all__ = ('Option',)
