@@ -19,7 +19,7 @@ from celery.five import string_t
 from celery.utils.functional import padlist
 from celery.utils.serialization import strtobool
 
-__all__ = ['AMQPAdmin', 'AMQShell', 'Spec', 'amqp']
+__all__ = ('AMQPAdmin', 'AMQShell', 'Spec', 'amqp')
 
 # Map to coerce strings to other types.
 COERCE = {bool: strtobool}
