@@ -13,7 +13,7 @@ from kombu.utils.objects import cached_property
 from celery import _state, signals
 from celery.exceptions import FixupWarning, ImproperlyConfigured
 
-__all__ = ['DjangoFixup', 'fixup']
+__all__ = ('DjangoFixup', 'fixup')
 
 ERR_NOT_INSTALLED = """\
 Environment variable DJANGO_SETTINGS_MODULE is defined
@@ -181,7 +181,7 @@ class DjangoWorkerFixup(object):
     def _close_database(self):
         for conn in self._db.connections.all():
             try:
-                conn.close()
+                conn.close_if_unusable_or_obsolete()
             except self.interface_errors:
                 pass
             except self.DatabaseError as exc:
@@ -191,7 +191,7 @@ class DjangoWorkerFixup(object):
 
     def close_cache(self):
         try:
-            self._cache.cache.close()
+            self._cache.close_caches()
         except (TypeError, AttributeError):
             pass
 
